@@ -230,7 +230,7 @@ class Optimizer:
         """Query and set bounds of the optimization variables.
         The :py:func:`bounds` method is an indexed property, meaning
         getting and setting this property requires an index and calls this function.
-        The power index (elements are seperated by comas) must contain atleast the following elements:
+        The power index (elements are separated by commas) must contain atleast the following elements:
 
         ======      =================   ==========================================================
         order       index name          valid options
@@ -428,7 +428,7 @@ class Optimizer:
                             'n_call_nlp_f', 'n_call_nlp_g', 'n_call_nlp_grad', 'n_call_nlp_grad_f',
                             'n_call_nlp_hess_l', 'n_call_nlp_jac_g', 'return_status', 'success', 't_proc_S',
                             't_proc_callback_fun', 't_proc_nlp_f', 't_proc_nlp_g', 't_proc_nlp_grad',
-                            't_proc_nlp_grad_f', 't_proc_nlp_hess_l', 't_proc_nlp_jac_g', 't_wall_S',
+                            't_proc_nlp_grad_f', 't_proc_nlp_hess_l', 't_proc_nlp_jac_g', 't_wall_total',
                             't_wall_callback_fun', 't_wall_nlp_f', 't_wall_nlp_g', 't_wall_nlp_grad', 't_wall_nlp_grad_f',
                             't_wall_nlp_hess_l', 't_wall_nlp_jac_g']
             # Create data_field(s) for the recorded (valid) stats.
