@@ -65,7 +65,7 @@ class Simulator(do_mpc.model.IteratedVariables):
         self.model = model
         do_mpc.model.IteratedVariables.__init__(self)
 
-        assert model.flags['setup'] == True, 'Model for simulator was not setup. After the complete model creation call model.setup_model().'
+        assert model.flags['setup'] == True, 'Model for simulator was not setup. After the complete model creation call model.setup().'
 
         self.data = Data(model)
 
@@ -106,7 +106,7 @@ class Simulator(do_mpc.model.IteratedVariables):
             raise Exception('You have not supplied a function to obtain the time-varying parameters defined in model. Use .set_tvp_fun() prior to setup.')
         # p_fun must be set, if p are defined in model.
         if self.flags['set_p_fun'] == False and self.model._p.size > 0:
-            raise Exception('You have not supplied a function to obtain the parameters defined in model. Use .set_p_fun() (low-level API) or .set_uncertainty_values() (high-level API) prior to setup.')
+            raise Exception('You have not supplied a function to obtain the parameters defined in model. Use .set_p_fun() prior to setup.')
 
         # Set dummy functions for tvp and p in case these parameters are unused.
         if not self.flags['set_tvp_fun']:
@@ -134,14 +134,14 @@ class Simulator(do_mpc.model.IteratedVariables):
 
         self._check_validity()
 
-        self.sim_x = sim_x =  struct_symSX([
+        self.sim_x = sim_x =  self.model.sv.sym_struct([
             entry('_x', struct=self.model._x)
             ])
-        self.sim_z = sim_z =  struct_symSX([
+        self.sim_z = sim_z =  self.model.sv.sym_struct([
             entry('_z', struct=self.model._z)
             ])
 
-        self.sim_p = sim_p = struct_symSX([
+        self.sim_p = sim_p = self.model.sv.sym_struct([
             entry('_u', struct=self.model._u),
             entry('_p', struct=self.model._p),
             entry('_tvp', struct=self.model._tvp),
@@ -510,6 +510,7 @@ class Simulator(do_mpc.model.IteratedVariables):
         self.data.update(_z = z0)
         self.data.update(_tvp = tvp0)
         self.data.update(_p = p0)
+        self.data.update(_y = y_next)
         self.data.update(_aux = aux0)
         self.data.update(_time = t0)
 
